@@ -103,5 +103,12 @@ PARSED_RESPONSE = "parsedResponse"
 OUTPUT = "output"
 YES = "Yes"
 NO = "No"
+
 # Follow up Commands
 CREATE_PROJECT_COMMAND = "neuralspace nlu create-project --help"
+UPLOAD_DATASET_COMMAND = "neuralspace nlu upload-dataset --help"
+INSTALL_APP_COMMAND = "neuralspace install-app --help"
+
+# checking command
+
+APP_IS_INSTALLED = "App is already installed"
