@@ -17,6 +17,7 @@ from neuralspace.constants import (
     COMMON_HEADERS,
     COMPLETED,
     COUNT,
+    CREATE_PROJECT_COMMAND,
     DATA,
     DEAD,
     ENTITIES,
@@ -143,8 +144,8 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
             )
             console.print(table)
             console.print(
-                "⏩ Upload data to your project using this command:"
-                " [dark_orange3]neuralspace nlu upload-dataset[/dark_orange3]"
+                f"⏩ Upload data to your project using this command:"
+                f" [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
             )
         else:
             console.print("> [red]ERROR[/red] Failed ❌  to create project")
@@ -172,6 +173,44 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
 
 
 def print_projects_table(projects: Dict[Text, Any]):
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Project Name", style="#c47900")
+    table.add_column("Project ID", style="#c47900")
+    table.add_column("Number of Intents", style="#c47900")
+    table.add_row(
+        "[bold]Login[/bold]",
+        "neuralspace [bold red]login[/bold red]",
+        "Login to the our platform and save credentials locally",
+    )
+    table.add_row(
+        "[bold]List Apps[/bold]",
+        "neuralspace [bold red]list-apps[/bold red]",
+        "List all the available apps in our platform and their respective codes",
+    )
+    table = PrettyTable()
+    table.field_names = [
+        "Project Name",
+        "Project ID",
+        "Number of Examples",
+        "Number of Intents",
+        "number of Models",
+        "Languages",
+    ]
+    for data in projects[DATA][PROJECTS]:
+        table.add_row(
+            [
+                data[PROJECT_NAME],
+                data[PROJECT_ID],
+                data[NUMBER_OF_EXAMPLES],
+                data[NUMBER_OF_INTENTS],
+                data[NUMBER_OF_MODELS],
+                data[LANGUAGE],
+            ]
+        )
+    logger.info(f"\n{table}")
+
+
+def train_table(projects: Dict[Text, Any]):
     table = PrettyTable()
     table.field_names = [
         "Project Name",
@@ -213,8 +252,8 @@ async def list_projects(
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info(
-                f"Your projects for Page {page_number} with Page Size: {page_size}"
+            console.print(
+                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📚 Your projects for Page {page_number} with Page Size: {page_size}"
             )
             print_projects_table(json_response)
         else:
@@ -278,6 +317,7 @@ async def list_examples(
 
 
 def print_models_table(models: Dict[Text, Any]):
+
     table = PrettyTable()
     table.field_names = [
         "Model ID",
@@ -319,7 +359,7 @@ async def list_models(
     page_number: int,
     page_size: int,
 ) -> Dict[Text, Any]:
-    logger.info(
+    console.print(
         f"Fetching models with filter: Project ID: {project_id}; Language: {language}; "
         f"Training Statuses: {training_status}"
     )
@@ -384,7 +424,10 @@ async def upload_dataset(
     )
     for chunk_id, example in track(
         enumerate(nlu_data[skip_first:]),
-        total=len(nlu_data[skip_first:]),
+        description="[bold orange4]uploading[/bold orange4]...",
+        total=len(
+            nlu_data[skip_first:],
+        ),
     ):
         batch = {PROJECT_ID: project_id, LANGUAGE: language, EXAMPLE: example}
         HEADERS = copy(COMMON_HEADERS)
@@ -398,23 +441,23 @@ async def upload_dataset(
             if is_success_status(response.status):
                 responses.append(json_response)
             else:
-                logger.error(f"Failed to upload example with text {example['text']}")
-                logger.debug(
-                    f"Failed on examples: \n {json.dumps(example, indent=4, ensure_ascii=False)}"
+                console.print(f"> [red]ERROR[/red] ❌ Failed to upload example with text [dark_orange3]{example['text']}[/dark_orange3]")
+                console.print(
+                    f"> Failed on example: \n {json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
-                logger.error(
-                    f"Platform response: \n {json.dumps(json_response, indent=4)}"
+                console.print(
+                    f"> Platform response: \n {json.dumps(json_response, indent=4)}"
                 )
                 error_examples.append(example)
                 if ignore_errors:
                     continue
                 else:
                     break
-    logger.info(f"Uploaded {len(responses)} examples")
-    logger.info(f"Failed on {len(error_examples)} examples")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Uploaded {len(responses)} examples")
+    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ❌ Failed on {len(error_examples)} examples")
     with open("failed_examples.json", "w") as f:
         json.dump(error_examples, f, ensure_ascii=False)
-        logger.info("Writing failed examples into failed_examples.json")
+        console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✍️ Writing failed examples into failed_examples.json")
     return responses
 
 
@@ -428,8 +471,8 @@ async def wait_till_training_completes(
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
         console.print(
-            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Waiting for training job to "
-            f"get done for model id: {model_id}"
+            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⏳ Waiting for training job to "
+            f"get trained for model id: {model_id}"
         )
         current_status = ""
         with console.status("...") as status:
