@@ -317,14 +317,14 @@ def nlu_delete_example(example_id: List[Text], log_level: Text):
     "-p",
     "--project-id",
     type=click.STRING,
-    required=True,
+    required=False,
     help="Project ID",
 )
 @click.option(
     "-L",
     "--language",
     type=click.STRING,
-    required=True,
+    required=False,
     help="Language",
 )
 @click.option(
@@ -350,26 +350,21 @@ def nlu_delete_example(example_id: List[Text], log_level: Text):
     default=1,
     help="Time to wait between consecutive pools.",
 )
-@click.option(
-    "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
-)
 def nlu_train_model(
-    project_id: Text,
-    language: Text,
-    model_name: Text,
-    wait: bool,
-    wait_interval: int,
-    log_level: Text,
+    project_id: Text, language: Text, model_name: Text, wait: bool, wait_interval: int
 ):
-    setup_logger(log_level=log_level)
-    print_logo()
-    if model_name is None:
-        model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
-    loop = asyncio.new_event_loop()
-    loop.run_until_complete(
-        train_model(project_id, language, model_name, wait, wait_time=wait_interval)
-    )
-    loop.run_until_complete(get_async_http_session().close())
+
+    if project_id and language:
+        print_logo()
+        if model_name is None:
+            model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
+        loop = asyncio.new_event_loop()
+        loop.run_until_complete(
+            train_model(project_id, language, model_name, wait, wait_time=wait_interval)
+        )
+        loop.run_until_complete(get_async_http_session().close())
+    else:
+        list_projects()
 
 
 @nlu.command(name="model-status")
